@@ -2,6 +2,7 @@ from .funcs import (
     contains,
     has_during,
     has_inside,
+    finishes,
     is_after,
     is_before,
     is_contained_by,
@@ -11,12 +12,13 @@ from .funcs import (
 from rdflib import Namespace
 from rdflib.plugins.sparql.operators import register_custom_function
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 TFUN = Namespace("https://w3id.org/timefuncs/")
 
 register_custom_function(TFUN.contains, contains, raw=True)
 register_custom_function(TFUN.hasDuring, has_during, raw=True)
 register_custom_function(TFUN.hasInside, has_inside, raw=True)
+register_custom_function(TFUN.finishes, finishes, raw=True)
 register_custom_function(TFUN.isAfter, is_after, raw=True)
 register_custom_function(TFUN.isBefore, is_before, raw=True)
 register_custom_function(TFUN.isContainedBy, is_contained_by, raw=True)
